@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
 """Mapping logic for UCLA CSV->Blacklight conversion."""
 
+import os
 import typing
 
+import yaml
+
 # import urllib.parse
 
 
@@ -16,7 +19,9 @@ def archival_collection(row: typing.Mapping[str, str]) -> str:
             else (
                 "" + f", Box {row['Box']}"
                 if "Box" in row
-                else "" + f", Folder {row['Folder']}" if "Folder" in row else ""
+                else "" + f", Folder {row['Folder']}"
+                if "Folder" in row
+                else ""
             )
         )
     )
@@ -37,7 +42,7 @@ def ark(row: typing.Mapping[str, str]) -> str:
     return ark_prefix + row["Item ARK"]
 
 
-def coordinates(row: typing.Mapping[str, str]) -> typing.List[str]:
+def coordinates(row: typing.Mapping[str, str]) -> tuple[str, str] | None:
     """Geographic coordinates.
 
     Args:
@@ -47,7 +52,7 @@ def coordinates(row: typing.Mapping[str, str]) -> typing.List[str]:
         A tuple of (latitude, longitude).
     """
     if "Latitude" not in row or "Longitude" not in row:
-        return []
+        return None
 
     return (row["Latitude"], row["Longitude"])
 
@@ -195,6 +200,28 @@ def access_group(row: typing.Mapping[str, str]) -> typing.List[str]:
     )
 
 
+def language(row: typing.Mapping[str, str]) -> typing.List[str] | None:
+    # Clunky way to handle language lookup, should be replaced by universal authority lookup
+    if row.get("Language"):
+        return [
+            LANGUAGE_MAPPING.get(lang_id, f"{lang_id}")
+            for lang_id in row["Language"].split("|~|")
+        ]
+    return None
+
+
+def create_language_mapping() -> typing.Dict[str, str]:
+    """Create a mapping of language IDs to terms from a YAML file."""
+    this_dir = os.path.dirname(os.path.abspath(__file__))
+    language_path = os.path.join(this_dir, "fields", "language.yml")
+    with open(language_path, "r") as f:
+        data = yaml.safe_load(f)
+
+    return {entry["id"]: entry["term"] for entry in data["terms"]}
+
+
+LANGUAGE_MAPPING = create_language_mapping()
+
 MappigDictValue = typing.Union[None, typing.Callable, str, typing.List[str]]
 MappingDict = typing.Dict[str, MappigDictValue]
 
@@ -283,7 +310,7 @@ FIELD_MAPPING: MappingDict = {
     "host_tesim": ["Host", "Name.host"],
     "human_readable_iiif_text_direction_ssi": "Text direction",
     "human_readable_iiif_viewing_hint_ssi": "viewingHint",
-    "human_readable_language_tesim": "Language",
+    "human_readable_language_tesim": language,
     "human_readable_related_record_title_ssm": ["Related Records"],
     "human_readable_resource_type_tesim": "Type.typeOfResource",
     "human_readable_rights_statement_tesim": "Rights.copyrightStatus",
@@ -425,7 +452,6 @@ FIELD_MAPPING: MappingDict = {
     "subject_tesim": "Subject",
     "subject_temporal_sim": "Subject temporal",
     "subject_temporal_tesim": "Subject temporal",
-    "subject_tesim": "Subject",
     "subject_topic_tesim": [
         "Subject topic",
         "Subject.conceptTopic",
